@@ -1,4 +1,4 @@
-from .base import SCMBackend
+from .base import SCMBackend, logger
 
 
 class Backend(SCMBackend):
@@ -13,11 +13,16 @@ class Backend(SCMBackend):
 
             self._repo = self
             filename = self.options.get('filename') or self.default_filename
-            rev_file = self.path if op.isfile(self.path) else op.join(self.path, filename)
+            rev_file = self.path if op.isfile(
+                self.path) else op.join(self.path, filename)
             with open(rev_file) as f:
                 self._revision = f.read().strip()
         except (AssertionError, IOError):
-            raise TypeError('Invalid path.')
+            message = 'Invalid path: {0}'.format(self.path)
+            if not self.options.get('silent'):
+                logger.error(message)
+
+            raise TypeError(message)
 
         return self._repo
 
